@@ -1,6 +1,6 @@
 /*!  \file 
 
-$Id: gdisp_kernel.c,v 1.11 2005/10/05 19:21:00 esteban Exp $
+$Id: gdisp_kernel.c,v 1.14 2005/12/05 22:01:30 esteban Exp $
 
 -----------------------------------------------------------------------
 
@@ -325,6 +325,7 @@ gdisp_createKernel (gint    argc,
   kernel->argTable               = argv;
   kernel->stepTimerPeriod        = GD_TIMER_MIN_PERIOD; /* milli-seconds */
   kernel->samplingThreadMustExit = TRUE;
+  kernel->retreiveAllSymbols     = FALSE;
 
   /*
    * Try to know whether a multi-threaded environment is available ?
@@ -356,7 +357,7 @@ gdisp_createKernel (gint    argc,
    * Initialise all plot systems.
    * Each plot system that is supported may provide several functions.
    */
-  kernel->currentPlotType = GD_PLOT_DEFAULT;
+  kernel->currentPlotType = GD_PLOT_TEXT;
 
   /* Remove size of 'psIsSupported' */
   functionSetSize = sizeof(PlotSystem_T) - sizeof(gboolean);
@@ -424,6 +425,7 @@ gdisp_createKernel (gint    argc,
 		    gdisp_activateRegisteredActions,
 		    (void*)kernel);
 
+
   /*
    * Remember :
    *  -  how to assign symbols to providers for sampling purpose.
@@ -459,6 +461,12 @@ gdisp_destroyKernel (Kernel_T *kernel)
    */
   gdisp_savePreferenceFile(kernel);
 
+  /*
+   * Stop all timers.
+   */
+  gdisp_stopLogoAnimation(kernel,TRUE /* stop all */);
+  gtk_timeout_remove(kernel->kernelTimerIdentity);
+
   /*
    * Destroy all fonts and pixmaps.
    */
@@ -468,7 +476,10 @@ gdisp_destroyKernel (Kernel_T *kernel)
   /*
    * Free Kernel.
    */
-  gtk_timeout_remove(kernel->kernelTimerIdentity);
+  if (kernel->ioFilename != (gchar*)NULL) {
+    g_free(kernel->ioFilename);
+  }
+
   g_ptr_array_free(kernel->kernelRegisteredActions,FALSE);
 
   memset(kernel,0,sizeof(Kernel_T));
