@@ -1,6 +1,6 @@
 /*!  \file 
 
-$Id: gdisp_kernel.h,v 1.18 2006/01/20 21:59:14 esteban Exp $
+$Id: gdisp_kernel.h,v 1.21 2006/02/15 21:39:07 esteban Exp $
 
 -----------------------------------------------------------------------
 
@@ -65,11 +65,13 @@ File      : Graphic Tool Kernel Interface.
 /*
  * Few defines.
  */
-#undef GD_LOAD_CONFIGURATION_WITH_ALL_SYMBOLS
+#undef  GD_LOAD_CONFIGURATION_WITH_ALL_SYMBOLS
 #define GD_UNREF_THINGS
 
+
 /*
  * 10 out of 170 colors.
+ * FIXME : allocate only these 10 colors, and not the entire colormap.
  */
 #define _RED_       3
 #define _GREEN_    10
@@ -390,24 +392,26 @@ typedef struct PlotSystem_T_ {
    */
 
   /* FIRST TYPE : Kernel only.                  */
-  void       (*psGetInformation)   (Kernel_T_Ptr,PlotSystemInfo_T*  );
-  void      *(*psCreate )          (Kernel_T_Ptr                    );
-  GArray    *(*psGetDropZones)     (Kernel_T_Ptr                    );
+  void       (*psGetInformation)     (Kernel_T_Ptr,PlotSystemInfo_T*     );
+  void      *(*psCreate )            (Kernel_T_Ptr                       );
+  GArray    *(*psGetDropZones)       (Kernel_T_Ptr                       );
 
   /* SECOND TYPE : Kernel and opaque structure. */
-  void       (*psDestroy)          (Kernel_T_Ptr,void*              );
-  void       (*psSetParent)        (Kernel_T_Ptr,void*,GtkWidget*   );
-  GtkWidget *(*psGetTopLevelWidget)(Kernel_T_Ptr,void*              );
-  void       (*psShow)             (Kernel_T_Ptr,void*              );
-  PlotType_T (*psGetType)          (Kernel_T_Ptr,void*              );
-  void       (*psSetDimensions)    (Kernel_T_Ptr,void*,guint,guint  );
-  void       (*psAddSymbols)       (Kernel_T_Ptr,void*,GList*,guchar);
-  GList     *(*psGetSymbols)       (Kernel_T_Ptr,void*,gchar        );
-  gboolean   (*psStartStep)        (Kernel_T_Ptr,void*              );
-  void       (*psStep)             (Kernel_T_Ptr,void*              );
-  void       (*psStopStep)         (Kernel_T_Ptr,void*              );
-  void       (*psTreatSymbolValues)(Kernel_T_Ptr,void*              );
-  guint      (*psGetPeriod)        (Kernel_T_Ptr,void*              );
+  void       (*psDestroy)            (Kernel_T_Ptr,void*                 );
+  void       (*psSetParent)          (Kernel_T_Ptr,void*,GtkWidget*      );
+  GtkWidget *(*psGetTopLevelWidget)  (Kernel_T_Ptr,void*                 );
+  void       (*psShow)               (Kernel_T_Ptr,void*                 );
+  PlotType_T (*psGetType)            (Kernel_T_Ptr,void*                 );
+  void       (*psSetDimensions)      (Kernel_T_Ptr,void*,guint,guint     );
+  void       (*psAddSymbols)         (Kernel_T_Ptr,void*,GList*,guchar   );
+  GList     *(*psGetSymbols)         (Kernel_T_Ptr,void*,gchar           );
+  void       (*psGetSymbolAttributes)(Kernel_T_Ptr,void*,Symbol_T*,GList*);
+  void       (*psSetSymbolAttributes)(Kernel_T_Ptr,void*,Symbol_T*,GList*);
+  gboolean   (*psStartStep)          (Kernel_T_Ptr,void*                 );
+  void       (*psStep)               (Kernel_T_Ptr,void*                 );
+  void       (*psStopStep)           (Kernel_T_Ptr,void*                 );
+  void       (*psTreatSymbolValues)  (Kernel_T_Ptr,void*                 );
+  guint      (*psGetPeriod)          (Kernel_T_Ptr,void*                 );
 
   /*
    * Kernel verification.
@@ -483,6 +487,7 @@ typedef struct KernelWidget_T_ {
   GtkWidget         *mainBoardOkButton;
   GtkWidget         *mainBoardStopButton;
   GtkWidget         *mainBoardOutputList;
+  GtkWidget         *mainBoardOutputScrolledWindow;
   guint              mainBoardOutputListSize;
   GtkWidget         *mainBoardLogoArea;
   GdkGC             *mainBoardLogoContext;
