@@ -1,6 +1,6 @@
 /*!  \file 
 
-$Id: gdisp_main.c,v 1.8 2006/01/20 21:59:14 esteban Exp $
+$Id: gdisp_main.c,v 1.9 2006/02/15 21:39:07 esteban Exp $
 
 -----------------------------------------------------------------------
 
@@ -171,6 +171,12 @@ main (int argc, char **argv)
   gtk_init(&argc, &argv);
 
 
+  /*
+   * Show splash screen.
+   */
+  gdisp_showSplashScreen();
+
+
   /*
    * Allocate memory for managing GDISP+ kernel.
    * Take into account user defined arguments passed to the application
