@@ -1,6 +1,6 @@
 /*!  \file 
 
-$Id: gdisp_mainBoard.c,v 1.8 2005/12/05 22:01:30 esteban Exp $
+$Id: gdisp_mainBoard.c,v 1.10 2006/02/15 21:39:07 esteban Exp $
 
 -----------------------------------------------------------------------
 
@@ -155,6 +155,11 @@ gdisp_quitItemHandler (gpointer factoryData,
 
   Kernel_T *kernel = (Kernel_T*)factoryData;
 
+  /*
+   * Update whole GUI.
+   */
+  gdisp_updateWholeGui();
+
   /*
    * Remember window position.
    */
@@ -181,10 +186,12 @@ gdisp_outputWrite(Kernel_T  *kernel,
 
 #define _TIME_STRING_MAX_LEN_ 80
 
-  gchar      timeString[_TIME_STRING_MAX_LEN_];
-  GtkWidget *listItem = (GtkWidget*)NULL;
-  GtkWidget *hBox     = (GtkWidget*)NULL;
-  time_t     nowTime;
+  gchar          timeString[_TIME_STRING_MAX_LEN_];
+  GtkWidget     *listItem       = (GtkWidget*)NULL;
+  GtkWidget     *hBox           = (GtkWidget*)NULL;
+  GtkWidget     *scrolledWindow = (GtkWidget*)NULL;
+  GtkAdjustment *vAdj           = (GtkAdjustment*)NULL;
+  time_t         nowTime;
 
   assert(kernel);
   assert(kernel->widgets.mainBoardWindow);
@@ -201,7 +208,6 @@ gdisp_outputWrite(Kernel_T  *kernel,
 	   localtime(&nowTime));
   g_string_prepend(string,timeString);
 
-
   /*
    * Create a 'list item' containing a 'label' and 'pixmap'.
    * Add this 'list item' into the main board output list.
@@ -219,10 +225,19 @@ gdisp_outputWrite(Kernel_T  *kernel,
 
   gtk_widget_show(listItem);
 
-  gtk_list_scroll_vertical(GTK_LIST(kernel->widgets.mainBoardOutputList),
-			   GTK_SCROLL_JUMP,
-			   (gfloat)1 /* bottom of the list */);
+  /*
+   * Makes the scrollbar go down.
+   */
+  scrolledWindow = kernel->widgets.mainBoardOutputScrolledWindow;
+  vAdj =
+    gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(scrolledWindow));
 
+  gtk_adjustment_set_value(vAdj,vAdj->upper /* maximum, thus bottom */);
+  /* gtk_adjustment_value_changed(vAdj); */
+
+  /*
+   * Increment output list size.
+   */
   kernel->widgets.mainBoardOutputListSize++;
 
   g_string_free(string,TRUE);
@@ -330,6 +345,11 @@ gdisp_launchAction ( GtkObject *siblingButton,
   Message_T         messageType    = GD_ERROR;
   gboolean          freeIoFilename = FALSE;
 
+  /*
+   * Update GUI.
+   */
+  gdisp_updateWholeGui();
+
   /*
    * Get back selected filename.
    */
@@ -823,6 +843,8 @@ gdisp_createMainBoard (Kernel_T *kernel)
 		     0     /* padding */);
   gtk_widget_show(scrolledWindow);
 
+  kernel->widgets.mainBoardOutputScrolledWindow = scrolledWindow;
+
   /*
    * Create the List widget.
    */
