@@ -1,6 +1,6 @@
 /*!  \file 
 
-$Id: gdisp_plot2D.c,v 1.15 2006/01/20 21:59:14 esteban Exp $
+$Id: gdisp_plot2D.c,v 1.17 2006/02/15 21:39:07 esteban Exp $
 
 -----------------------------------------------------------------------
 
@@ -51,6 +51,13 @@ File      : 2D plot system.
 #include <math.h>
 
 
+/*
+ * GTK add-ons.
+ */
+/*
+#include <gtk/gtkdatabox.h>
+*/
+
 /*
  * For key manipulation.
  */
@@ -1626,8 +1633,8 @@ gdisp_plot2DButtonPress (GtkWidget      *area,
   }
 
   /*
-   * 'button3' removes the selected symbol from the list.
-   * 'shift' + 'button3' removes all symbols.
+   * 'button3'
+   * 'shift' + 'button3'
    */
   if (event->state & GDK_SHIFT_MASK) {
 
@@ -2226,6 +2233,48 @@ gdisp_getSymbolsFromPlot2D (Kernel_T *kernel,
 }
 
 
+/*
+ * Get symbol attributes in order to be saved into the configuration.
+ */
+static void
+gdisp_getSymbolAttributesPlot2D (Kernel_T *kernel,
+				 void     *data,
+				 Symbol_T *symbol,
+				 GList    *attributeList)
+{
+
+  /* Plot2D_T *plot = (Plot2D_T*)data; */
+
+  /*
+   * Return all attributes of a symbol.
+   */
+
+  /* nothing by now */
+
+}
+
+
+/*
+ * Set symbol attributes from the configuration.
+ */
+static void
+gdisp_setSymbolAttributesPlot2D (Kernel_T *kernel,
+				 void     *data,
+				 Symbol_T *symbol,
+				 GList    *attributeList)
+{
+
+  /* Plot2D_T *plot = (Plot2D_T*)data; */
+
+  /*
+   * Store all attributes of a symbol.
+   */
+
+  /* nothing by now */
+
+}
+
+
 /*
  * Real time Starting Step Action.
  */
@@ -2635,22 +2684,24 @@ gdisp_initPlot2DSystem (Kernel_T     *kernel,
    * that remain 'static' here, but accessible from everywhere
    * via the kernel.
    */
-  plotSystem->psCreate            = gdisp_createPlot2D;
-  plotSystem->psDestroy           = gdisp_destroyPlot2D;
-  plotSystem->psSetParent         = gdisp_setPlot2DParent;
-  plotSystem->psGetTopLevelWidget = gdisp_getPlot2DTopLevelWidget;
-  plotSystem->psShow              = gdisp_showPlot2D;
-  plotSystem->psGetType           = gdisp_getPlot2DType;
-  plotSystem->psAddSymbols        = gdisp_addSymbolsToPlot2D;
-  plotSystem->psGetSymbols        = gdisp_getSymbolsFromPlot2D;
-  plotSystem->psSetDimensions     = gdisp_setPlot2DInitialDimensions;
-  plotSystem->psStartStep         = gdisp_startStepOnPlot2D;
-  plotSystem->psStep              = gdisp_stepOnPlot2D;
-  plotSystem->psStopStep          = gdisp_stopStepOnPlot2D;
-  plotSystem->psGetInformation    = gdisp_getPlot2DInformation;
-  plotSystem->psTreatSymbolValues = gdisp_treatPlot2DSymbolValues;
-  plotSystem->psGetPeriod         = gdisp_getPlot2DPeriod;
-  plotSystem->psGetDropZones      = gdisp_getPlot2DDropZones;
+  plotSystem->psCreate              = gdisp_createPlot2D;
+  plotSystem->psDestroy             = gdisp_destroyPlot2D;
+  plotSystem->psSetParent           = gdisp_setPlot2DParent;
+  plotSystem->psGetTopLevelWidget   = gdisp_getPlot2DTopLevelWidget;
+  plotSystem->psShow                = gdisp_showPlot2D;
+  plotSystem->psGetType             = gdisp_getPlot2DType;
+  plotSystem->psAddSymbols          = gdisp_addSymbolsToPlot2D;
+  plotSystem->psGetSymbols          = gdisp_getSymbolsFromPlot2D;
+  plotSystem->psGetSymbolAttributes = gdisp_getSymbolAttributesPlot2D;
+  plotSystem->psSetSymbolAttributes = gdisp_setSymbolAttributesPlot2D;
+  plotSystem->psSetDimensions       = gdisp_setPlot2DInitialDimensions;
+  plotSystem->psStartStep           = gdisp_startStepOnPlot2D;
+  plotSystem->psStep                = gdisp_stepOnPlot2D;
+  plotSystem->psStopStep            = gdisp_stopStepOnPlot2D;
+  plotSystem->psGetInformation      = gdisp_getPlot2DInformation;
+  plotSystem->psTreatSymbolValues   = gdisp_treatPlot2DSymbolValues;
+  plotSystem->psGetPeriod           = gdisp_getPlot2DPeriod;
+  plotSystem->psGetDropZones        = gdisp_getPlot2DDropZones;
 
   /*
    * Manage debug traces.
